@@ -38,13 +38,13 @@ namespace ffmpegthumbnailer
 MovieDecoder::MovieDecoder(const string& filename, AVFormatContext* pavContext)
 : m_VideoStream(-1)
 , m_pFormatContext(pavContext)
-, m_pVideoCodecContext(NULL)
-, m_pVideoCodec(NULL)
-, m_pVideoStream(NULL)
-, m_pFrame(NULL)
-, m_pFrameBuffer(NULL)
-, m_pPacket(NULL)
-, m_FormatContextWasGiven(pavContext != NULL)
+, m_pVideoCodecContext(nullptr)
+, m_pVideoCodec(nullptr)
+, m_pVideoStream(nullptr)
+, m_pFrame(nullptr)
+, m_pFrameBuffer(nullptr)
+, m_pPacket(nullptr)
+, m_FormatContextWasGiven(pavContext != nullptr)
 , m_AllowSeek(true)
 {
     initialize(filename);
@@ -59,32 +59,25 @@ void MovieDecoder::initialize(const string& filename)
 {
     av_register_all();
     avcodec_register_all();
+    avformat_network_init();
 
     string inputFile = filename == "-" ? "pipe:" : filename;
-    m_AllowSeek = (filename != "-") && (filename.find("rtsp://") != 0);
+    m_AllowSeek = (filename != "-") && (filename.find("rtsp://") != 0) && (filename.find("udp://") != 0);
     
-#if LIBAVCODEC_VERSION_MAJOR < 53
-    if ((!m_FormatContextWasGiven) && av_open_input_file(&m_pFormatContext, inputFile.c_str(), NULL, 0, NULL) != 0)
-#else
-	if ((!m_FormatContextWasGiven) && avformat_open_input(&m_pFormatContext, inputFile.c_str(), NULL, NULL) != 0)
-#endif
+    if ((!m_FormatContextWasGiven) && avformat_open_input(&m_pFormatContext, inputFile.c_str(), nullptr, nullptr) != 0)
     {
-		destroy();
+        destroy();
         throw logic_error(string("Could not open input file: ") + filename);
     }
 
-#if LIBAVCODEC_VERSION_MAJOR < 53
-    if (av_find_stream_info(m_pFormatContext) < 0)
-#else
-	if (avformat_find_stream_info(m_pFormatContext, NULL) < 0)
-#endif
+	if (avformat_find_stream_info(m_pFormatContext, nullptr) < 0)
     {
-		destroy();
+        destroy();
         throw logic_error(string("Could not find stream information"));
     }
 
     initializeVideo();
-    m_pFrame = avcodec_alloc_frame();
+    m_pFrame = av_frame_alloc();
 }
 
 void MovieDecoder::destroy()
@@ -92,39 +85,35 @@ void MovieDecoder::destroy()
     if (m_pVideoCodecContext)
     {
         avcodec_close(m_pVideoCodecContext);
-        m_pVideoCodecContext = NULL;
+        m_pVideoCodecContext = nullptr;
     }
 
     if ((!m_FormatContextWasGiven) && m_pFormatContext)
     {
-#if LIBAVCODEC_VERSION_MAJOR < 53
-        av_close_input_file(m_pFormatContext);
-        m_pFormatContext = NULL;
-#else
         avformat_close_input(&m_pFormatContext);
-#endif
     }
 
     if (m_pPacket)
     {
         av_free_packet(m_pPacket);
         delete m_pPacket;
-        m_pPacket = NULL;
+        m_pPacket = nullptr;
     }
 
     if (m_pFrame)
     {
-        av_free(m_pFrame);
-        m_pFrame = NULL;
+        av_frame_free(&m_pFrame);
     }
 
     if (m_pFrameBuffer)
     {
         av_free(m_pFrameBuffer);
-        m_pFrameBuffer = NULL;
+        m_pFrameBuffer = nullptr;
     }
 
     m_VideoStream = -1;
+    
+    avformat_network_deinit();
 }
 
 string MovieDecoder::getCodec()
@@ -141,11 +130,7 @@ void MovieDecoder::initializeVideo()
 {
     for (unsigned int i = 0; i < m_pFormatContext->nb_streams; ++i)
     {
-#if LIBAVCODEC_VERSION_MAJOR < 53
-        if (m_pFormatContext->streams[i]->codec->codec_type == CODEC_TYPE_VIDEO)
-#else
         if (m_pFormatContext->streams[i]->codec->codec_type == AVMEDIA_TYPE_VIDEO)
-#endif
         {
             m_pVideoStream = m_pFormatContext->streams[i];
             m_VideoStream = i;
@@ -161,20 +146,16 @@ void MovieDecoder::initializeVideo()
     m_pVideoCodecContext = m_pFormatContext->streams[m_VideoStream]->codec;
     m_pVideoCodec = avcodec_find_decoder(m_pVideoCodecContext->codec_id);
 
-    if (m_pVideoCodec == NULL)
+    if (m_pVideoCodec == nullptr)
     {
-        // set to NULL, otherwise avcodec_close(m_pVideoCodecContext) crashes
-        m_pVideoCodecContext = NULL;
+        // set to nullptr, otherwise avcodec_close(m_pVideoCodecContext) crashes
+        m_pVideoCodecContext = nullptr;
         throw logic_error("Video Codec not found");
     }
 
     m_pVideoCodecContext->workaround_bugs = 1;
 
-#if LIBAVCODEC_VERSION_MAJOR < 53
-    if (avcodec_open(m_pVideoCodecContext, m_pVideoCodec) < 0)
-#else
-	if (avcodec_open2(m_pVideoCodecContext, m_pVideoCodec, NULL) < 0)
-#endif
+	if (avcodec_open2(m_pVideoCodecContext, m_pVideoCodec, nullptr) < 0)
     {
         throw logic_error("Could not open video codec");
     }
@@ -356,7 +337,7 @@ void MovieDecoder::convertAndScaleFrame(PixelFormat format, int scaledSize, bool
 #ifdef LATEST_GREATEST_FFMPEG
 	// Enable this when it hits the released ffmpeg version
     SwsContext* scaleContext = sws_alloc_context();
-    if (scaleContext == NULL)
+    if (scaleContext == nullptr)
     {
 		throw std::logic_error("Failed to allocate scale context");
 	}
@@ -376,7 +357,7 @@ void MovieDecoder::convertAndScaleFrame(PixelFormat format, int scaledSize, bool
 		throw std::logic_error("Failed to set colorspace details");
 	}
 
-	if (sws_init_context(scaleContext, NULL, NULL) < 0)
+	if (sws_init_context(scaleContext, nullptr, nullptr) < 0)
 	{
 		sws_freeContext(scaleContext);
 		throw std::logic_error("Failed to initialise scale context");
@@ -385,15 +366,15 @@ void MovieDecoder::convertAndScaleFrame(PixelFormat format, int scaledSize, bool
     
     SwsContext* scaleContext = sws_getContext(m_pVideoCodecContext->width, m_pVideoCodecContext->height,
                                               m_pVideoCodecContext->pix_fmt, scaledWidth, scaledHeight,
-                                              format, SWS_BICUBIC, NULL, NULL, NULL);
+                                              format, SWS_BICUBIC, nullptr, nullptr, nullptr);
 
-    if (NULL == scaleContext)
+    if (nullptr == scaleContext)
     {
         throw logic_error("Failed to create resize context");
     }
 
-    AVFrame* convertedFrame = NULL;
-    uint8_t* convertedFrameBuffer = NULL;
+    AVFrame* convertedFrame = nullptr;
+    uint8_t* convertedFrameBuffer = nullptr;
 
     createAVFrame(&convertedFrame, &convertedFrameBuffer, scaledWidth, scaledHeight, format);
     
@@ -448,7 +429,7 @@ void MovieDecoder::calculateDimensions(int squareSize, bool maintainAspectRatio,
 
 void MovieDecoder::createAVFrame(AVFrame** pAvFrame, uint8_t** pFrameBuffer, int width, int height, PixelFormat format)
 {
-    *pAvFrame = avcodec_alloc_frame();
+    *pAvFrame = av_frame_alloc();
 
     int numBytes = avpicture_get_size(format, width, height);
     *pFrameBuffer = reinterpret_cast<uint8_t*>(av_malloc(numBytes));
