@@ -1,6 +1,6 @@
 #include <iostream>
 
-#include <gtest/gtest.h>
+#include "gtest/gtest.h"
 
 int main(int argc, char **argv) {
     std::cout << "Running ffmpegthumbnailer tests" << std::endl;
